==> apache-streampipes-0.93.0-source-release.zip: apache-streampipes-0.93.0/ui/src/app/connect/services/adapter-template.service.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Injectable } from '@angular/core';
import { SpAdapterTemplateDialogComponent } from '../dialog/adapter-template/adapter-template-dialog.component';
import { DialogService, PanelType } from '@streampipes/shared-ui';
import { StaticPropertyUnion } from '../../../../projects/streampipes/platform-services/src/lib/model/gen/streampipes-model';

@Injectable({ providedIn: 'root' })
export class AdapterTemplateService {
    constructor(private dialogService: DialogService) {}

    getDialog(configs: StaticPropertyUnion[], appId: string) {
        return this.dialogService.open(SpAdapterTemplateDialogComponent, {
            panelType: PanelType.SLIDE_IN_PANEL,
            title: 'Create configuration template',
            width: '50vw',
            data: {
                configs: configs,
                appId: appId,
            },
        });
    }
}

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/ui/src/app/connect/services/adapter-template.service.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Injectable } from '@angular/core';
import { SpAdapterTemplateDialogComponent } from '../dialog/adapter-template/adapter-template-dialog.component';
import { DialogService, PanelType } from '@streampipes/shared-ui';
import { StaticPropertyUnion } from '@streampipes/platform-services';

@Injectable({ providedIn: 'root' })
export class AdapterTemplateService {
    constructor(private dialogService: DialogService) {}

    getDialog(configs: StaticPropertyUnion[], appId: string) {
        return this.dialogService.open(SpAdapterTemplateDialogComponent, {
            panelType: PanelType.SLIDE_IN_PANEL,
            title: 'Create configuration template',
            width: '50vw',
            data: {
                configs: configs,
                appId: appId,
            },
        });
    }
}
